// Double inclusion protection
#ifndef ANTENNA_LIB_H
#define ANTENNA_LIB_H
// Structure for passing information about the GW source and detectors
struct InputStruct {
   // orbital orientation in degrees, 0 to 180. Zero degrees has
   // orbital angular momentum pointing to the earth
   double iota;
   // orientation of long axis of ellipse, 0 to 360, in degrees CCW
   // from North
   double psi;
   // orientation of detector arms away from actual, 0 to 360, in
   // degrees CCW when viewed from directly overhead
   // Ordering is LLO, LHO, VIRGO
   double orientation[3];
};

// Structure for returning information about the response.  The array
// elements are in the order LLO, LHO, VIRGO
struct OutputStruct {
   // detector names, null terminated string
   char name[3][8];
   // amplitude of sin function, dimensionless
   double amp[3];
   // phase of sin function, in degrees from 0 to 360
   double phase[3];
   // time delays, in milliseconds
   double dt[3];
};


// Function gets antenna responses, using information in the 
// input structure (not modified) and writing to the output structure.
void get_antenna(struct OutputStruct *out, struct InputStruct *in);

#endif // ANTENNA_LIB_H
