/******************************************************************************
 *   Copyright (C) 2008 by Oliver Bock                                        *
 *   oliver.bock[AT]aei.mpg.de                                                *
 *                                                                            *
 *   This file is part of PulsatingScience.                                   *
 *                                                                            *
 *   PulsatingScience is free software: you can redistribute it and/or modify *
 *   it under the terms of the GNU General Public License as published        *
 *   by the Free Software Foundation, version 3 of the License.               *
 *                                                                            *
 *   PulsatingScience is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the             *
 *   GNU General Public License for more details.                             *
 *                                                                            *
 *   You should have received a copy of the GNU General Public License        *
 *   along with PulsatingScience. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                            *
 ******************************************************************************/

#ifndef PULSATINGSCIENCE_H
#define PULSATINGSCIENCE_H

#include <QtGui/QMainWindow>
#include <QtGui/QMessageBox>
#include <QtGui/QShortcut>
#include <QDesktopServices>
#include <QUrl>

#include "ui_pulsatingscience.h"


class PulsatingScience : public QMainWindow
{
    Q_OBJECT

public:
    PulsatingScience(QWidget *parent = 0);
    ~PulsatingScience();

    void closeEvent(QCloseEvent *event);

public slots:
    void on_sliderLHOAngle_valueChanged(int value);
    void on_sliderLLOAngle_valueChanged(int value);
    void on_sliderVirgoAngle_valueChanged(int value);
    void on_sliderSourceIota_valueChanged(int value);
    void on_sliderSourceInclination_valueChanged(int value);

    void on_actionReset_triggered();
    void fullscreenToggled();
    void on_actionFullscreen_toggled(bool checked);
    void menuBarToggled();
    void on_actionMenu_bar_toggled(bool checked);
    void on_actionStatus_bar_toggled(bool checked);
    void on_dockAnimControl_visibilityChanged(bool visible);
    void on_dockAnimControl_topLevelChanged(bool topLevel);

    void on_actionAbout_triggered();

    void toggleHiddenDemoMode();

    void userInactivityCallback();

protected:
    bool eventFilter(QObject *obj, QEvent *event);

private:
    void userActivity();
    void saveOrRestoreInitialAnimationSettings();

    Ui::PulsatingScienceClass ui;

    QShortcut *m_menuBarShortcut;
    QShortcut *m_fullscreenShortcut;
    QShortcut *m_fullscreenESCShortcut;
    QShortcut *m_hiddenShortcut;

    bool m_menuBarVisible;
    bool m_statusBarVisible;
    bool m_animControlVisible;
    bool m_animControlFloating;
    bool m_hiddenDemoModeActivated;

    QTimer *m_inactivityTimer;
};

#endif // PULSATINGSCIENCE_H
